Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2344)

Unified Diff: chrome/browser/media/router/create_presentation_connection_request.h

Issue 2627463003: Convert MediaRouter mojom apis to intake url::Origin objects instead of strings (Closed)
Patch Set: Add missing dependency for extensions_renderer_resources target Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/media/router/create_presentation_connection_request.h
diff --git a/chrome/browser/media/router/create_presentation_connection_request.h b/chrome/browser/media/router/create_presentation_connection_request.h
index 41e5da492c4e8bbbb24c28792129c8df67260055..dc702af5c112de3c05f04ff9c75ed71e7131cb66 100644
--- a/chrome/browser/media/router/create_presentation_connection_request.h
+++ b/chrome/browser/media/router/create_presentation_connection_request.h
@@ -16,13 +16,15 @@
#include "chrome/browser/media/router/render_frame_host_id.h"
#include "content/public/browser/presentation_service_delegate.h"
-class GURL;
-
namespace content {
struct PresentationError;
struct PresentationSessionInfo;
} // namespace content
+namespace url {
+class Origin;
+} // namespace url
+
namespace media_router {
class RouteRequestResult;
@@ -42,13 +44,14 @@ class CreatePresentationConnectionRequest {
content::PresentationSessionErrorCallback;
// |presentation_url|: The presentation URL of the request. Must be a valid
// URL.
// |frame_url|: The URL of the frame that initiated the presentation request.
// |success_cb|: Callback to invoke when the request succeeds. Must be valid.
// |erorr_cb|: Callback to invoke when the request fails. Must be valid.
CreatePresentationConnectionRequest(
const RenderFrameHostId& render_frame_host_id,
const std::vector<GURL>& presentation_urls,
- const GURL& frame_url,
+ const url::Origin& frame_origin,
const PresentationSessionSuccessCallback& success_cb,
const PresentationSessionErrorCallback& error_cb);
~CreatePresentationConnectionRequest();
@@ -42,13 +44,14 @@ class CreatePresentationConnectionRequest {
// |presentation_url|: The presentation URL of the request. Must be a valid
// URL.
- // |frame_url|: The URL of the frame that initiated the presentation request.
+ // |frame_origin|: The origin of the frame that initiated the presentation
+ // request.
// |success_cb|: Callback to invoke when the request succeeds. Must be valid.
// |erorr_cb|: Callback to invoke when the request fails. Must be valid.
« no previous file with comments | « chrome/browser/media/router/BUILD.gn ('k') | chrome/browser/media/router/create_presentation_connection_request.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698